==> aerospike-client-java-3.3.3.zip: aerospike-client-java-3.3.3/client/src/com/aerospike/client/async/AsyncTouch.java <==
/*
 * Copyright 2012-2017 Aerospike, Inc.
 *
 * Portions may be licensed to Aerospike, Inc. under one or more contributor
 * license agreements WHICH ARE COMPATIBLE WITH THE APACHE LICENSE, VERSION 2.0.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.aerospike.client.async;

import java.nio.ByteBuffer;

import com.aerospike.client.AerospikeException;
import com.aerospike.client.Key;
import com.aerospike.client.cluster.Node;
import com.aerospike.client.cluster.Partition;
import com.aerospike.client.listener.WriteListener;
import com.aerospike.client.policy.WritePolicy;

public final class AsyncTouch extends AsyncSingleCommand {
	private final WritePolicy writePolicy;
	private final WriteListener listener;
	private final Key key;
	private final Partition partition;
		
	public AsyncTouch(AsyncCluster cluster, WritePolicy writePolicy, WriteListener listener, Key key) {
		super(cluster, writePolicy);
		this.writePolicy = writePolicy;
		this.listener = listener;
		this.key = key;
		this.partition = new Partition(key);
	}

	public AsyncTouch(AsyncTouch other) {
		super(other);
		this.writePolicy = other.writePolicy;
		this.listener = other.listener;
		this.key = other.key;
		this.partition = other.partition;
	}

	@Override
	protected AsyncCommand cloneCommand() {
		return new AsyncTouch(this);
	}

	@Override
	protected void writeBuffer() {
		setTouch(writePolicy, key);
	}

	@Override
	protected Node getNode() {	
		return cluster.getMasterNode(partition);
	}

	@Override
	protected void parseResult(ByteBuffer byteBuffer) {
		int resultCode = byteBuffer.get(5) & 0xFF;
		
		if (resultCode != 0) {
			throw new AerospikeException(resultCode);
		}
	}

	@Override
	protected void onSuccess() {
		if (listener != null) {
			listener.onSuccess(key);
		}
	}	

	@Override
	protected void onFailure(AerospikeException e) {
		if (listener != null) {
			listener.onFailure(e);
		}
	}
}

==> aerospike-client-java-4.1.0.zip: aerospike-client-java-4.1.0/client/src/com/aerospike/client/async/AsyncTouch.java <==
/*
 * Copyright 2012-2017 Aerospike, Inc.
 *
 * Portions may be licensed to Aerospike, Inc. under one or more contributor
 * license agreements WHICH ARE COMPATIBLE WITH THE APACHE LICENSE, VERSION 2.0.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.aerospike.client.async;

import com.aerospike.client.AerospikeException;
import com.aerospike.client.Key;
import com.aerospike.client.cluster.Partition;
import com.aerospike.client.listener.WriteListener;
import com.aerospike.client.policy.WritePolicy;

public final class AsyncTouch extends AsyncCommand implements AsyncSingleCommand {
	private final WriteListener listener;
	private final WritePolicy writePolicy;
	private final Key key;
		
	public AsyncTouch(WriteListener listener, WritePolicy writePolicy, Key key) {
		super(writePolicy, new Partition(key), null, false, false);
		this.listener = listener;
		this.writePolicy = writePolicy;
		this.key = key;
	}

	@Override
	protected void writeBuffer() {
		setTouch(writePolicy, key);
	}

	@Override
	public void parseResult() {
		if (resultCode != 0) {
			throw new AerospikeException(resultCode);
		}
	}

	@Override
	protected void onSuccess() {
		if (listener != null) {
			listener.onSuccess(key);
		}
	}	

	@Override
	protected void onFailure(AerospikeException e) {
		if (listener != null) {
			listener.onFailure(e);
		}
	}
}
